'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

var _video = require('video.js');

var _video2 = _interopRequireDefault(_video);

var _utils = require('./utils.js');

var _utils2 = _interopRequireDefault(_utils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Component = _video2.default.getComponent('Component');
var ModalDialog = _video2.default.getComponent('ModalDialog');

var DEFAULTS = {
	caption: '',
	message: '',
	startAt: {
		txt: "Start time of webcast",
		val: '' //timestamp 
	},
	duration: {
		txt: "Duration of webcast",
		val: '' // sec or 'auto'
	},
	countdownTxt: "Time left before webcast start",
	onCountdownFinish: function onCountdownFinish() {
		this.player_.play();
	},
	timezone: 0,
	time: 0, // sec 
	interval: 1 //sec
};

/**
 * The dialog component for showing countdown
 *
 * @param {Object} player   Main Player
 * @param {Object=} options Object of option names and values
 * @extends Component
 */

var CountdownStartDialog = function (_ModalDialog) {
	_inherits(CountdownStartDialog, _ModalDialog);

	function CountdownStartDialog(player, options) {
		_classCallCheck(this, CountdownStartDialog);

		var options_ = _video2.default.mergeOptions(DEFAULTS, options);
		options_.uncloseable = true;

		var _this = _possibleConstructorReturn(this, (CountdownStartDialog.__proto__ || Object.getPrototypeOf(CountdownStartDialog)).call(this, player, options_));

		_this.init();
		return _this;
	}

	_createClass(CountdownStartDialog, [{
		key: 'init',
		value: function init() {
			if (this.options_.time > 0) {
				this.timeLoad = new Date();
				this.fillWith(this.createContent());
				this.show();
				this.startCowntdown();
			}
		}
	}, {
		key: 'startCowntdown',
		value: function startCowntdown() {
			var _this2 = this;

			var timeLeft = this.options_.time,
			    el = this.$('.vjs-countdown-start-timer-val'),
			    updTime = function updTime() {
				_video2.default.insertContent(el, _utils2.default.formatTime(timeLeft));
				timeLeft = _this2.options_.time - (new Date() - _this2.timeLoad) / 1000;
			};

			this.player_.addClass('vjs-countdown-start-counting');
			updTime();
			var interval = this.player_.setInterval(function () {
				if (timeLeft > 0) {
					updTime();
				} else {
					_this2.player_.clearInterval(interval);
					_this2.hide();
					_this2.player_.removeClass('vjs-countdown-start-counting');
					_utils2.default.isFunction(_this2.options_.onCountdownFinish) && _this2.options_.onCountdownFinish.call(_this2);
				}
			}, this.options_.interval);
		}
	}, {
		key: 'buildCSSClass',
		value: function buildCSSClass() {
			return 'vjs-countdown-start-dialog ' + _get(CountdownStartDialog.prototype.__proto__ || Object.getPrototypeOf(CountdownStartDialog.prototype), 'buildCSSClass', this).call(this);
		}
	}, {
		key: 'createContent',
		value: function createContent() {
			var doc = _video2.default.createEl('div', {
				className: 'vjs-countdown-start-doc'
			}, {
				role: 'document'
			});
			_video2.default.appendContent(doc, [this.createHeading_(), this.createMessage_(), this.createInfoFields_(), this.createCountdown_()]);
			return doc;
		}
	}, {
		key: 'createHeading_',
		value: function createHeading_() {
			if (!this.options_.caption) return;

			var heading = _video2.default.createEl('div', {
				className: 'vjs-countdown-start-caption'
			}, {
				'role': 'heading'
			});
			_video2.default.insertContent(heading, this.localize(this.options_.caption));
			return heading;
		}
	}, {
		key: 'createMessage_',
		value: function createMessage_() {
			if (!this.options_.message) return;

			var message = _video2.default.createEl('div', {
				className: 'vjs-countdown-start-message'
			});
			_video2.default.insertContent(message, this.localize(this.options_.message));
			return message;
		}
	}, {
		key: 'createInfoFields_',
		value: function createInfoFields_() {
			var _this3 = this;

			var infoFields = _video2.default.createEl('div', {
				className: 'vjs-countdown-start-info'
			});

			if (this.options_.startAt.val) {
				_video2.default.appendContent(infoFields, [this.localize(this.options_.startAt.txt) + ': ', _utils2.default.formatDateTime(this.options_.startAt.val * 1, this.options_.timezone), _video2.default.createEl("br")]);
			}

			var duration = this.options_.duration.val;
			if (duration) {
				var durationVal = _video2.default.createEl('span', {
					className: 'vjs-countdown-start-duration-val'
				}),
				    cb = function cb() {
					_video2.default.insertContent(durationVal, Math.round(duration / 60).toString() + ' ');
				};
				_video2.default.appendContent(infoFields, [this.localize(this.options_.duration.txt) + ': ', durationVal, this.localize("Min of content") + '.']);
				if (duration == 'auto') {
					this.player_.on('loadedmetadata', function () {
						duration = _this3.player_.duration();
						cb();
					});
				} else {
					cb();
				}
			}

			return infoFields;
		}
	}, {
		key: 'createCountdown_',
		value: function createCountdown_() {
			var countdown = _video2.default.createEl('div', {
				className: 'vjs-countdown-start-timer'
			});

			var countdownTxt = _video2.default.createEl('span', {
				className: 'vjs-countdown-start-timer-text'
			});
			_video2.default.insertContent(countdownTxt, this.localize(this.options_.countdownTxt) + ':');

			var countdownVal = _video2.default.createEl('span', {
				className: 'vjs-countdown-start-timer-val'
			});

			_video2.default.appendContent(countdown, [countdownTxt, countdownVal]);

			return countdown;
		}
	}]);

	return CountdownStartDialog;
}(ModalDialog);

Component.registerComponent('CountdownStartDialog', CountdownStartDialog);
exports.default = CountdownStartDialog;